precision mediump float;			// Set the default precision to medium. We don't need as high of a precision in the fragment shader.
uniform lowp sampler2D u_Texture;	// The input texture.
uniform lowp sampler2D u_alpha;		// The alpha image
varying lowp vec4 v_Color;			// This is the color from the vertex shader interpolated across the triangle per fragment.

varying vec2 v_TexCoordinate;		// Interpolated texture coordinate per fragment.

uniform vec4 u_ClipRect; // = vec4(100, 100, 200, 200); // clip is in viewport space; y = 0 is bottom of screen 
uniform float u_PVRMult;
uniform float u_Factor;
uniform vec3  u_TargetColor;



float getClipping(vec2 position, vec4 clipRect)
{
	vec2 inside = step(clipRect.xy, position.xy) * step(position.xy, clipRect.zw);
	return inside.x * inside.y;
}

void main()
{
	float clipping = getClipping(gl_FragCoord.xy, u_ClipRect);

	lowp vec4 textureSample;
	textureSample = texture2D(u_Texture, v_TexCoordinate);

	lowp vec4 alphaSample;
	alphaSample = texture2D(u_alpha, v_TexCoordinate);

	vec4 base = u_PVRMult > 0.0 ? textureSample * alphaSample : vec4(textureSample.rgb, alphaSample.a);
	base.rgb *= u_PVRMult > 0.0 ? base.a : 1.0;

	vec3 targetColor = u_TargetColor * base.a;
	vec3 mixedColor = mix(v_Color.rgb * base.rgb, targetColor, u_Factor);
	gl_FragColor = vec4(mixedColor.rgb, base.a) * clipping;
}
